| swipeR-shiny | R Documentation |
Output and render functions for using swipeR within Shiny applications.
swipeROutput(outputId, width = "100%", height = "400px")
renderSwipeR(expr, env = parent.frame(), quoted = FALSE)
outputId |
output variable to read from |
width, height |
must be a valid CSS unit (like |
expr |
an expression that generates a |
env |
the environment in which to evaluate |
quoted |
Boolean, whether |
swipeROutput returns an output element that can be included
in a Shiny UI, and renderSwipeR returns a shiny.render.function
object that can be assigned to an output slot in a Shiny server.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.