Output and render functions for using swipeR within Shiny applications.
swipeROutput(outputId, width = "100%", height = "400px")renderSwipeR(expr, env = parent.frame(), quoted = FALSE)
swipeROutput returns an output element that can be included
in a Shiny UI, and renderSwipeR returns a shiny.render.function
object that can be assigned to an output slot in a Shiny server.
output variable to read from
must be a valid CSS unit (like "100%",
"400px", "auto") or a number, which will be coerced to a
string and have "px" appended
an expression that generates a swipeR carousel
the environment in which to evaluate expr
Boolean, whether expr is a quoted expression
(with quote()); this is useful if you want to save an expression
in a variable